C+
C NAME:
C	Time1Delta
C PURPOSE:
C	Get difference between 1-element standard times
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	subroutine Time1Delta(t,u,dt)
C INPUTS:
C	t	integer		1-element standard time
C	u	integer		1-element standard time
C OUTPUTS
C	dt	integer		1-element time difference t-u
C PROCEDURE:
C MODIFICATION HISTORY:
C	OCT-2003, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C-
	    integer	t
	    integer	u
	    integer	dt

	dt = t-u

	return
	end
